.. perun documentation master file, created by
   sphinx-quickstart on Mon Apr 24 09:25:39 2023.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. attention::
   This project is under active development. For any issues, features requests, or if you would like to contribute, our `github page`_ page is the place to go.

.. include:: ../README.rst
   :end-line: 42

.. toctree::
   :maxdepth: 2

   quickstart
   install
   usage
   configuration
   data



Indices and tables
------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

.. Links
.. _github page: https://github.com/Helmholtz-AI-Energy/perun
